@@ -1,7 +1,5 @@
 package Path::Hilbert;
 
-use strict;
-use warnings;
 use 5.012;
 use utf8;
 
@@ -9,7 +7,18 @@ use Exporter qw( import );
 
 our @EXPORT = qw( xy2d d2xy );
 
-our $VERSION = '1.205';
+our $VERSION = '2.000';
+
+BEGIN {
+    if (eval "require Path::Hilbert::XS") {
+        *xy2d = \&Path::Hilbert::XS::xy2d;
+        *d2xy = \&Path::Hilbert::XS::d2xy;
+    }
+    else {
+        *xy2d = \&_xy2d;
+        *d2xy = \&_d2xy;
+    }
+};
 
 # optional constructor if you want OO-style
 sub new {
@@ -19,7 +28,7 @@ sub new {
 }
 
 # convert (x,y) to d
-sub xy2d {
+sub _xy2d {
     my ($side, $x, $y) = @_;
     my $n = _valid_n($side);
     my ($X, $Y) = map { int($_ + 0.5) } ($x, $y);
@@ -41,7 +50,7 @@ sub xy2d {
 }
 
 # convert d to (x,y)
-sub d2xy {
+sub _d2xy {
     my ($side, $d) = @_;
     my $n = _valid_n($side);
     my $T = int($d + 0.5);
@@ -108,7 +117,7 @@ Path::Hilbert - A no-frills converter between 1D and 2D spaces using the Hilbert
 
 =head1 VERSION
 
-Version 1.204
+Version 2.000
 
 =head1 SYNOPSIS
 
@@ -122,7 +131,7 @@ Version 1.204
     my $t = $space->xy2d($u, $v);
     die unless $t == 127;
 
-=head1 Description
+=head1 DESCRIPTION
 
 See Wikipedia for a description of the Hilbert curve, and why it's a good idea.
 
@@ -196,6 +205,13 @@ was provided via new().
 
 =back
 
+=head1 AUTOMATIC USE OF XS
+
+As of v2.000, this module automatically loads and uses L<Path::Hilbert::XS> if
+possible (i.e. when that module is installed), except when
+L<Path::Hilbert::BigInt> is requested (which still tries GMP, Pari, and
+FastCalc in that order, all of which are slower than even the non-XS module).
+
 =head1 CAVEATS
 
 If your platform has I<$n> bit integers, things will go badly if you try a side
@@ -205,14 +221,7 @@ C<integer> support for your platform.
 
 =head1 BUGS
 
-Please let me know via the CPAN RT if you find any algorithmic defects. I'm
-well aware that there are a number of opportunities to speed it up.
-
-=head1 TODO
-
-Speed it up. XS? Memoization?
-
-For a faster (non-Bignum) implementation, see L<Path::Hilbert::XS>.
+Please let me know via the CPAN RT if you find any algorithmic defects.
 
 =head1 AUTHOR
 
