@@ -1,7 +1,5 @@
 package Path::Hilbert::BigInt;
 
-use strict;
-use warnings;
 use 5.012;
 use utf8;
 
@@ -12,7 +10,7 @@ use Exporter qw( import );
 
 our @EXPORT = qw( xy2d d2xy );
 
-our $VERSION = '1.204';
+our $VERSION = '2.000';
 
 # optional constructor if you want OO-style
 sub new {
@@ -92,7 +90,7 @@ Path::Hilbert::BigInt - A slower, no-frills converter between very large 1D and
 
 =head1 VERSION
 
-Version 1.204
+Version 2.000
 
 =head1 SYNOPSIS
 
@@ -101,7 +99,7 @@ Version 1.204
     my $d = xy2d(8192, $x, $y);
     die unless $d == 21_342_865;
 
-=head1 Description
+=head1 DESCRIPTION
 
 See the documentation for L<Path::Hilbert>, except s/Path::Hilbert/Path::Hilbert::BigInt/ as needed.
 
